context("CSIndicators::WindPowerDensity tests")

# dat1
wind <- NULL
wind$data <- array(rweibull(n = 100, shape = 2, scale = 6), 
                   c(member = 10, lat = 2, lon = 5))
wind$coords <- list(lat =  c(40, 41), lon = 1:5)
variable <- list(varName = 'sfcWind', 
                 metadata = list(sfcWind = list(level = 'Surface')))
wind$attrs <- list(Variable = variable, Datasets = 'synthetic', 
                   when = Sys.time(), Dates = '1990-01-01 00:00:00')
class(wind) <- 's2dv_cube'

###########################################################################
test_that("1. Input checks", {
  # Check 's2dv_cube'
  expect_error(
    CST_WindPowerDensity(wind = 1), 
    "Parameter 'wind' must be of the class 's2dv_cube'."
  )
  # Dates subset
  expect_warning(
    CST_WindPowerDensity(wind = wind, start = list(1,3), end = list(1,7)), 
    paste0("Dimensions in 'wind' element 'attrs$Dates' are missed and ",
           "all data would be used."), 
    fixed = TRUE
  )
  # start and end
  expect_error(
    WindPowerDensity(wind = wind$data, dates = wind$attrs$Dates, 
                     start = c(1,2), end = c(2,3)), 
    paste0("Parameter 'start' and 'end' must be lists indicating the ",
           "day and the month of the period start and end.")
  )
})

###########################################################################
test_that("2. Output checks", {
  expect_equal(
    CST_WindPowerDensity(wind = wind)$attrs$Variable$varName, 
    'WindPowerDensity'
  )
  expect_equal(
    dim(CST_WindPowerDensity(wind = wind)$data), 
    c(member = 10, lat = 2, lon = 5)
  )
})

